 function[hit_rate, t_avg] = main(v1) 

    %Air density
    rho_air = 1.226; 

    %Earth's gravitation [m/s^2]
    g = [0, 0, -9.81];

    %Wind velocity
    v_w = wind_configuration(0, 0, 0);
    v = 60;

    %Nozzle position and angles
    H = 7.0;
    alpha = (v1/360) * 2 * pi;
    %beta = (0/360) * 2 * pi;

    %Time
    h = 0.002;
    t0 = 0;

    %Distance from track
    distance = 1;

    %Intermediate positions
    pos_x = [];
    pos_y = [];
    pos_z = [];

    %flat fan angle
    theta = (50/360) * 2*pi;

    %Landing positions
    end_x = [];
    end_y = [];

    %Fall times
    fall_time = [];

    %Hit rate
    droplets_total = 0;
    droplets_hit = 0;

    n = 2; %number of nozzles
    for i = 1:n

    H_i = H;
    beta_i = [45, -45] * (1/360) * 2 * pi;
        for j = 1:1000
            alpha_j = random('unif', alpha - pi/24, alpha + pi/24);
            beta_j = normrnd(beta_i(i), theta/4);                                   %normal distribution of droplets
            %beta_j = random('unif', beta - (theta/2), beta + (theta/2));           %uniform distribution of droplets
            [p0, v_i] = nozzle_configuration(H_i, v, alpha_j, beta_j);              %[Height, exitation speed, horizontal angle, rotational angle]

            %Creating a droplet with radius R
            [R, rho_water] = droplet;

            [ pos_xn, pos_yn, pos_zn, tn ] = euler_solver(g, v_i, p0, h, v_w, R, rho_air, rho_water, 0);
            pos_x = [pos_x, pos_xn ];
            pos_y = [pos_y, pos_yn ];
            pos_z = [pos_z, pos_zn ];

            end_x = [ end_x , pos_x(end)];
            end_y = [ end_y , pos_y(end)];

            fall_time = [fall_time, tn];

            %Calculating hit rate
            droplets_total = droplets_total + 1;

            if pos_x(end) > distance && pos_x(end) < distance + 5
               droplets_hit = droplets_hit + 1; 
            end

        end 
    end

    hit_rate = (droplets_hit / droplets_total) *100;
    

    t_avg = mean(fall_time);

    avg_X = mean(end_x);
    avg_Y = mean(end_y);
    
    strmin = {['Hit rate = ',num2str(hit_rate), '%'], ['Avg. position = [', num2str(avg_X),',',  num2str(avg_Y),']']};
    
    stravgpos = ['Avg. position = [', num2str(avg_X),',',  num2str(avg_Y),']'];

%     %PLOTS OF THE PATH AND LANDING PROJECTION
% 
%      pbaspect([1 1 1])
%      f = plot3(pos_x, pos_y, pos_z, '.');
%      f.Color = 'c';
%      f.MarkerSize = 1;
%      xlabel('x')
%      ylabel('y')
%      zlabel('Height')
%      text(2,8, strmin, 'HorizontalAlignment','left');
%      grid on
%      axis equal
%      hold on
%      %plot(end_x, end_y, 'O')
%      rectangle('Position',[distance -12 5 24], 'FaceColor', [0.5,0.5,0.5])
%  
%      hold off
%  
%      figure
%      hold on
%      xlabel('x [m]')
%      ylabel('y [m]')
%      axis equal
%      grid on
%      text(7,0, strmin, 'HorizontalAlignment','left');
%      text(7,-0.5, stravgpos, 'HorizontalAlignment','left');
%      rectangle('Position',[distance -12 5 24], 'FaceColor', [0.9,0.9,0.9])
%      plot(end_x, end_y, 'O', 'MarkerEdgeColor', uint8([0 80 158]) )
%      hold off 

    
end


